@@ -950,7 +950,7 @@ public class JAXBElementProviderTest {
         };
 
         ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        provider.writeTo(list, ArrayList.class, type, //NOPMD
+        provider.writeTo(list, ArrayList.class, type,
             new Annotation[0], MediaType.TEXT_XML_TYPE, new MetadataMap<String, Object>(), bos);
 
         String expected = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
@@ -1453,8 +1453,7 @@ public class JAXBElementProviderTest {
             return props;
         }
 
-        @SuppressWarnings("rawtypes")
-        public <A extends XmlAdapter> A getAdapter(Class<A> type) {
+        public <A extends XmlAdapter<?, ?>> A getAdapter(Class<A> type) {
             return null;
         }
 
@@ -1513,13 +1512,11 @@ public class JAXBElementProviderTest {
 
         }
 
-        @SuppressWarnings("rawtypes")
-        public void setAdapter(XmlAdapter adapter) {
+        public <A extends XmlAdapter<?, ?>> void setAdapter(A adapter) {
 
         }
 
-        @SuppressWarnings("rawtypes")
-        public <A extends XmlAdapter> void setAdapter(Class<A> type, A adapter) {
+        public <A extends XmlAdapter<?, ?>> void setAdapter(Class<A> type, A adapter) {
 
         }
 
