@@ -18,8 +18,8 @@
  */
 package org.apache.cxf.systest.jaxrs.jaxws;
 
-import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.XmlRootElement;
+import jakarta.xml.bind.annotation.XmlType;
 
 
 @XmlRootElement(name = "User")
